<?php
class Lickstats {
	const API_PATH = 'https://api.lickstats.com/v1';
	protected static $tags = array();
	protected static $initiated = false;
	protected static $tags_per_id = array();
	protected static $is_active = null;
	public static function init() {
		if ( ! self::$initiated ) {
			self::init_hooks();
		}
	}

	/*
		Is the plugin active?
	 */
	protected static function is_active(){
		if(!isset(self::$is_active)){
			self::$is_active = get_option('lickstats_active', false);
		}
		return self::$is_active;
	}

	/**
	 * Initializes WordPress hooks
	 */
	private static function init_hooks() {
		self::$initiated = true;

		if(!self::is_active()){ //Plugin is inactive
			return;
		}

		add_action( 'the_post', array('Lickstats', 'the_post_hook') );
		add_action( 'wp_footer', array('Lickstats', 'wp_footer_hook'), 100 );

	}

	/*
		Log in and load user data. Throws an exception if no results come back.
	 */
	public static function log_in($email, $password){

        $response = wp_remote_post(self::API_PATH.'/login', array(
                'method' => 'POST',
                'timeout' => 15,
                'redirection' => 0,
                'httpversion' => '1.0',
                'blocking' => true,
                'headers' => array(),
                'body' => array('email' => $email, 'password' => $password),
                'cookies' => array()
            )
        );

        if (is_wp_error($response)){
            throw new \Exception($response->get_error_message());
        } else {
            $response_code = $response['response']['code'];
            $response_body = $response['body'];
            if($response_code != 200){
                switch ($response_code){
                    case 400:
                        throw new \Exception('Invalid email or password');
                        break;
                    case 401:
                        throw new \Exception('Invalid credentials');
                        break;
                    default:
                        throw new \Exception('Could not log in');
                }
            }
            else {
                return json_decode($response_body);
            }
        }
	}

	/*
		Footer hook (enqueues the script only of the plugin is active and there is an account type/id associated to it)
	 */
	public static function wp_footer_hook(){
		if(!self::is_active()){
			return;
		}
        $domains      = get_option('lickstats_crossdomains', array());
		$account_type = strtolower(get_option('lickstats_account_type', null));
		if(empty($account_type)){
			return; //No account type? Most likely misconfigured, not loading.
		}
		$script  = '<script>';
		$script .= '(function(){var n,e;window.ls={accountId:'.json_encode(get_option('lickstats_account_id', null)).',crossdomains:'.json_encode($domains).',pending:[],push:function(){return this.pending.push(arguments)}},e=document.getElementsByTagName("script")[0],n=document.createElement("script"),n.async=!0,n.src="//cdn.lickstats.com/plugin-v1.js",e.parentNode.insertBefore(n,e)}).call(this);';
		if ($account_type == 'enterprise'){
            $script .= 'ls.push(\'tags\', {tags: '.json_encode(self::get_all_tags()).'});';
        }
		$script .= '</script>';
		echo $script;
	}

	/*
		Getting tags from a post only if we haven't requested them before
	 */
	protected static function get_post_tags($post_id){
		if(!isset(self::$tags_per_id[$post_id])){
			self::$tags_per_id[$post_id] = array();
			$tags = wp_get_post_tags($post_id);
			foreach($tags as $tag){
				self::$tags_per_id[$post_id][] = $tag->slug;
			}
		}
		return self::$tags_per_id[$post_id];

	}

	protected static function get_all_tags(){
		$tags = array();
		foreach(self::$tags_per_id as $k=>$v){ //Iterate all tags
			foreach($v as $tag){
				if(!isset($tags[$tag])){
					$tags[$tag] = true;
				}
			}
		}
		return array_keys($tags);
	}

	/*
		Called whenever the_post is called within the loop :)
	 */
	public static function the_post_hook($post){
		if(!is_single($post)){
			return;
		}
		$tags = self::get_post_tags($post->ID);
	}
}
